pub fn load_settings() -> Result<Settings>Expand description
Load GUI application settings (settings.json).
Returns Settings::default when the file does not exist yet (first
run) or is malformed (the file is preserved for manual recovery).
pub fn load_settings() -> Result<Settings>Load GUI application settings (settings.json).
Returns Settings::default when the file does not exist yet (first
run) or is malformed (the file is preserved for manual recovery).